@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.19';
+  $App::Pocoirc::VERSION = '0.20';
 }
 
 use strict;
@@ -15,6 +15,7 @@ sub POE::Kernel::USE_SIGCHLD () { return 1 }
 use App::Pocoirc::Status;
 use IO::Handle;
 use POE;
+use POE::Component::Client::DNS;
 use POSIX 'strftime';
 
 sub new {
@@ -117,6 +118,9 @@ sub _start {
     $kernel->sig(TERM => 'sig_term');
     $self->_status("Started (pid $$)");
 
+    # create the shared DNS resolver
+    $self->{resolver} = POE::Component::Client::DNS->spawn();
+
     # construct global plugins
     $self->_status("Constructing global plugins");
     $self->{global_plugs} = $self->_create_plugins(delete $self->{cfg}{global_plugins});
@@ -137,7 +141,10 @@ sub _start {
         $self->{local_plugs}{$network} = $self->_create_plugins(delete $opts->{local_plugins});
 
         $self->_status('Spawning IRC component', $network);
-        my $irc = $class->spawn(%$opts);
+        my $irc = $class->spawn(
+            %$opts,
+            Resolver => $self->{resolver},
+        );
         push @{ $self->{ircs} }, [$network, $irc];
     }
 
@@ -362,6 +369,8 @@ sub _shutdown {
             $obj->yield('shutdown');
         }
     }
+
+    $self->{resolver}->shutdown();
     $self->{shutdown} = 1;
 
     return;
